@@ -6,7 +6,7 @@
 #![deny(rustdoc::all)]
 #![allow(rustdoc::missing_doc_code_examples)]
 
-use anchor_lang::prelude::*;
+use anchor_lang::{prelude::*, solana_program::pubkey::PUBKEY_BYTES};
 use anchor_spl::token::{Mint, Token, TokenAccount};
 use continuation_router::{ActionType, RouterActionProcessor};
 use vipers::prelude::*;
@@ -52,7 +52,7 @@ pub mod add_decimals {
         let multiplier = unwrap_int!(10u64.checked_pow(added_decimals as u32));
 
         let wrapper = &mut ctx.accounts.wrapper;
-        wrapper.__nonce = *unwrap_int!(ctx.bumps.get("wrapper"));
+        wrapper.__nonce = unwrap_bump!(ctx, "wrapper");
         wrapper.decimals = decimals;
         wrapper.multiplier = multiplier;
         wrapper.wrapper_underlying_mint = ctx.accounts.underlying_mint.key();
@@ -158,7 +158,6 @@ pub mod add_decimals {
 
 /// Accounts for initializing a new wrapper.
 #[derive(Accounts)]
-#[instruction(nonce: u8)]
 pub struct InitializeWrapper<'info> {
     /// The WrappedToken account.
     #[account(
@@ -169,6 +168,7 @@ pub struct InitializeWrapper<'info> {
             &[wrapper_mint.decimals]
         ],
         bump,
+        space = 8 + WrappedToken::LEN,
         payer = payer
     )]
     pub wrapper: Account<'info, WrappedToken>,
@@ -303,6 +303,8 @@ pub struct WrappedToken {
 }
 
 impl WrappedToken {
+    pub const LEN: usize = 1 + 8 + PUBKEY_BYTES * 3 + 1;
+
     pub fn to_wrapped_amount(&self, amount: u64) -> Option<u64> {
         self.multiplier.checked_mul(amount)
     }
